# bme280.py
# adapted from Pimoroni
# Version July 21, 2019

from microbit import i2c, sleep
import gc, struct

_a = 0x76
qnh = 1013.25 # hPa

def read(r, n):
    i2c.write(_a, bytes([r]), True)
    return i2c.read(_a, n)
    
def write(r, v):
    i2c.write(_a, bytes([r, v]))
 
def getValues():
    gc.collect()
    T1, T2, T3, P1, P2, P3, P4, P5, P6, P7, P8, P9, _, H1, H2, H3,  E4, E5, E6, H6 = struct.unpack("<HhhHhhhhhhhhbBhBbBbb", comp)

    H4 = (E5 & 0x0f) | (E4 << 4)
    H5 = (E5 >> 4) | (E6 << 4)
        
    raw = read(0xF7, 8)

    raw_temp = (raw[3]<<12)+(raw[4]<<4)+(raw[5]>>4)
    raw_press = (raw[0]<<12)+(raw[1]<<4)+(raw[2]>>4)
    raw_hum = (raw[6]<<8)+raw[7]

    v1 = (raw_temp/16384.0-T1/1024.0)*T2
    v2 = (raw_temp/131072.0-T1/8192.0)*(raw_temp/131072.0-T1/8192.0)*T3
    temp = (v1+v2)/5120.0
    z = (v1+v2)

    v1 = z/2.0-64000.0
    v2 = v1*v1*P6/32768.0
    v2 = v2+v1*P5*2
    v2 = v2/4.0+P4*65536.0
    v1 = (P3*v1*v1/524288.0+P2*v1)/524288.0
    v1 = (1.0+v1/32768.0)*P1
    p = 1048576.0-raw_press
    p = (p-v2/4096.0)*6250.0/v1
    v1 = P9*p*p/2147483648.0
    v2 = p*P8/32768.0
    p = p+(v1+v2+P7)/16.0

    h = float(z) - 76800.0
    h = (raw_hum - (float(H4) * 64.0 + float(H5) / 16384.0 * h)) * (
    float(H2) / 65536.0 * (1.0 + float(H6) / 67108864.0 * h * (
    1.0 + float(H3) / 67108864.0 * h)))
    h = h * (1.0 - float(H1) * h / 524288.0)
    if h > 100:
        h = 100
    elif h < 0:
        h = 0

    return temp, h, p / 100.0, 44330.0 * (1.0 - pow(p / 100 / qnh, (1.0/5.255)))

write(0xE0, 0xB6) 
sleep(200)
write(0xF4, 0b10110111)
sleep(200)
write(0xF5, 0b10010000)
sleep(200)
comp = read(0x88, 26)
comp += read(0xe1, 7)

